diff --git a/accessible/base/nsCoreUtils.cpp b/accessible/base/nsCoreUtils.cpp
index 0bd318e7ee..7bd4c1eca4 100644
--- a/accessible/base/nsCoreUtils.cpp
+++ b/accessible/base/nsCoreUtils.cpp
@@ -150,7 +150,7 @@ nsCoreUtils::DispatchTouchEvent(EventMessage aMessage, int32_t aX, int32_t aY,
// XXX: Touch has an identifier of -1 to hint that it is synthesized.
RefPtr t = new dom::Touch(-1, LayoutDeviceIntPoint(aX, aY),
- nsIntPoint(1, 1), 0.0f, 1.0f);
+ LayoutDeviceIntPoint(1, 1), 0.0f, 1.0f);
t->SetTarget(aContent);
event.touches.AppendElement(t);
nsEventStatus status = nsEventStatus_eIgnore;
diff --git a/b2g/app/moz.build b/b2g/app/moz.build
index 44de14ba4f..1330a6bd13 100644
--- a/b2g/app/moz.build
+++ b/b2g/app/moz.build
@@ -28,11 +28,8 @@ USE_LIBS += [
for var in ('MOZ_APP_NAME', 'MOZ_APP_VERSION', 'MOZ_UPDATER'):
DEFINES[var] = CONFIG[var]
-GENERATED_INCLUDES += [
- '/build',
-]
-
LOCAL_INCLUDES += [
+ '!/build',
'/toolkit/xre',
'/xpcom/base',
'/xpcom/build',
diff --git a/b2g/app/nsBrowserApp.cpp b/b2g/app/nsBrowserApp.cpp
index b7fcea85f5..e7fcc431a5 100644
--- a/b2g/app/nsBrowserApp.cpp
+++ b/b2g/app/nsBrowserApp.cpp
@@ -34,7 +34,7 @@
#endif
#ifdef MOZ_WIDGET_GONK
-#include "GonkDisplay.h"
+#include "BootAnimation.h"
#endif
#include "BinaryPath.h"
@@ -148,8 +148,8 @@ static int do_main(int argc, char* argv[])
}
#ifdef MOZ_WIDGET_GONK
- /* Called to start the boot animation */
- (void) mozilla::GetGonkDisplay();
+ /* Start boot animation */
+ mozilla::StartBootAnimation();
#endif
if (appini) {
diff --git a/browser/app/moz.build b/browser/app/moz.build
index 0a691bdb2a..d6d5e837c4 100644
--- a/browser/app/moz.build
+++ b/browser/app/moz.build
@@ -6,7 +6,6 @@
DIRS += ['profile/extensions']
-
if CONFIG['OS_ARCH'] == 'WINNT' and CONFIG['MOZ_ASAN']:
GeckoProgram(CONFIG['MOZ_APP_NAME'])
else:
@@ -27,11 +26,8 @@ DEFINES['APP_VERSION'] = CONFIG['MOZ_APP_VERSION']
DEFINES['XPCOM_GLUE'] = True
-GENERATED_INCLUDES += [
- '/build',
-]
-
LOCAL_INCLUDES += [
+ '!/build',
'/toolkit/xre',
'/xpcom/base',
'/xpcom/build',
diff --git a/browser/app/profile/palemoon.js b/browser/app/profile/palemoon.js
index 019f884e22..46f1c28d38 100644
--- a/browser/app/profile/palemoon.js
+++ b/browser/app/profile/palemoon.js
@@ -919,8 +919,13 @@ pref("dom.ipc.plugins.enabled.x86_64", true);
pref("dom.ipc.plugins.enabled", true);
#endif
-// If decoding-via-gmp is turned on for
-
-
-
-
-
-
diff --git a/dom/workers/test/serviceworkers/test_gzip_redirect.html b/dom/workers/test/serviceworkers/test_gzip_redirect.html
index f21d0fffd2..f8c2ac082c 100644
--- a/dom/workers/test/serviceworkers/test_gzip_redirect.html
+++ b/dom/workers/test/serviceworkers/test_gzip_redirect.html
@@ -76,7 +76,8 @@
SpecialPowers.pushPrefEnv({"set": [
["dom.serviceWorkers.exemptFromPerDomainMax", true],
["dom.serviceWorkers.enabled", true],
- ["dom.serviceWorkers.testing.enabled", true]
+ ["dom.serviceWorkers.testing.enabled", true],
+ ['dom.serviceWorkers.interception.enabled', true],
]}, runTest);
diff --git a/dom/workers/test/serviceworkers/test_https_origin_after_redirect.html b/dom/workers/test/serviceworkers/test_https_origin_after_redirect.html
index 3878a1df6d..b780bc07b3 100644
--- a/dom/workers/test/serviceworkers/test_https_origin_after_redirect.html
+++ b/dom/workers/test/serviceworkers/test_https_origin_after_redirect.html
@@ -48,6 +48,7 @@
["dom.serviceWorkers.exemptFromPerDomainMax", true],
["dom.serviceWorkers.enabled", true],
["dom.serviceWorkers.testing.enabled", true],
+ ['dom.serviceWorkers.interception.enabled', true],
["dom.caches.enabled", true],
]}, runTest);
};
diff --git a/dom/workers/test/serviceworkers/test_https_origin_after_redirect_cached.html b/dom/workers/test/serviceworkers/test_https_origin_after_redirect_cached.html
index 81a1d1da0e..ba2801c1b8 100644
--- a/dom/workers/test/serviceworkers/test_https_origin_after_redirect_cached.html
+++ b/dom/workers/test/serviceworkers/test_https_origin_after_redirect_cached.html
@@ -48,6 +48,7 @@
["dom.serviceWorkers.exemptFromPerDomainMax", true],
["dom.serviceWorkers.enabled", true],
["dom.serviceWorkers.testing.enabled", true],
+ ['dom.serviceWorkers.interception.enabled', true],
["dom.caches.enabled", true],
]}, runTest);
};
diff --git a/dom/workers/test/serviceworkers/test_notificationclick.html b/dom/workers/test/serviceworkers/test_notificationclick.html
index 04d63184b0..cb4322c05b 100644
--- a/dom/workers/test/serviceworkers/test_notificationclick.html
+++ b/dom/workers/test/serviceworkers/test_notificationclick.html
@@ -49,6 +49,7 @@ https://bugzilla.mozilla.org/show_bug.cgi?id=916893
["dom.serviceWorkers.enabled", true],
["dom.serviceWorkers.testing.enabled", true],
["dom.webnotifications.workers.enabled", true],
+ ['dom.serviceWorkers.interception.enabled', true],
["notification.prompt.testing", true],
]}, runTest);
diff --git a/dom/workers/test/serviceworkers/test_opaque_intercept.html b/dom/workers/test/serviceworkers/test_opaque_intercept.html
index fe0598f454..db86ffacec 100644
--- a/dom/workers/test/serviceworkers/test_opaque_intercept.html
+++ b/dom/workers/test/serviceworkers/test_opaque_intercept.html
@@ -77,6 +77,7 @@
["dom.serviceWorkers.exemptFromPerDomainMax", true],
["dom.serviceWorkers.enabled", true],
["dom.serviceWorkers.testing.enabled", true],
+ ['dom.serviceWorkers.interception.enabled', true],
["dom.serviceWorkers.interception.opaque.enabled", true],
["dom.caches.enabled", true],
]}, runTest);
diff --git a/dom/workers/test/serviceworkers/test_origin_after_redirect.html b/dom/workers/test/serviceworkers/test_origin_after_redirect.html
index 42f8b35caa..58efa61b79 100644
--- a/dom/workers/test/serviceworkers/test_origin_after_redirect.html
+++ b/dom/workers/test/serviceworkers/test_origin_after_redirect.html
@@ -48,6 +48,7 @@
["dom.serviceWorkers.exemptFromPerDomainMax", true],
["dom.serviceWorkers.enabled", true],
["dom.serviceWorkers.testing.enabled", true],
+ ['dom.serviceWorkers.interception.enabled', true],
["dom.caches.enabled", true],
]}, runTest);
};
diff --git a/dom/workers/test/serviceworkers/test_origin_after_redirect_cached.html b/dom/workers/test/serviceworkers/test_origin_after_redirect_cached.html
index 2a19e20dec..78d44ca530 100644
--- a/dom/workers/test/serviceworkers/test_origin_after_redirect_cached.html
+++ b/dom/workers/test/serviceworkers/test_origin_after_redirect_cached.html
@@ -48,6 +48,7 @@
["dom.serviceWorkers.exemptFromPerDomainMax", true],
["dom.serviceWorkers.enabled", true],
["dom.serviceWorkers.testing.enabled", true],
+ ['dom.serviceWorkers.interception.enabled', true],
["dom.caches.enabled", true],
]}, runTest);
};
diff --git a/dom/workers/test/serviceworkers/test_origin_after_redirect_to_https.html b/dom/workers/test/serviceworkers/test_origin_after_redirect_to_https.html
index dcac11aea1..d6b45a6ef4 100644
--- a/dom/workers/test/serviceworkers/test_origin_after_redirect_to_https.html
+++ b/dom/workers/test/serviceworkers/test_origin_after_redirect_to_https.html
@@ -48,6 +48,7 @@
["dom.serviceWorkers.exemptFromPerDomainMax", true],
["dom.serviceWorkers.enabled", true],
["dom.serviceWorkers.testing.enabled", true],
+ ['dom.serviceWorkers.interception.enabled', true],
["dom.caches.enabled", true],
]}, runTest);
};
diff --git a/dom/workers/test/serviceworkers/test_origin_after_redirect_to_https_cached.html b/dom/workers/test/serviceworkers/test_origin_after_redirect_to_https_cached.html
index b70d1704e8..e63cb7e753 100644
--- a/dom/workers/test/serviceworkers/test_origin_after_redirect_to_https_cached.html
+++ b/dom/workers/test/serviceworkers/test_origin_after_redirect_to_https_cached.html
@@ -48,6 +48,7 @@
["dom.serviceWorkers.exemptFromPerDomainMax", true],
["dom.serviceWorkers.enabled", true],
["dom.serviceWorkers.testing.enabled", true],
+ ['dom.serviceWorkers.interception.enabled', true],
["dom.caches.enabled", true],
]}, runTest);
};
diff --git a/dom/workers/test/serviceworkers/test_periodic_https_update.html b/dom/workers/test/serviceworkers/test_periodic_https_update.html
deleted file mode 100644
index 4a84dd92e8..0000000000
--- a/dom/workers/test/serviceworkers/test_periodic_https_update.html
+++ /dev/null
@@ -1,26 +0,0 @@
-
-
-
-
diff --git a/b2g/app/b2g.js b/b2g/app/b2g.js
index c255f60614..0d39655820 100644
--- a/b2g/app/b2g.js
+++ b/b2g/app/b2g.js
@@ -1081,8 +1081,9 @@ pref("gfx.vsync.refreshdriver", true);
pref("dom.activities.developer_mode_only", "import-app");
// mulet apparently loads firefox.js as well as b2g.js, so we have to explicitly
// disable serviceworkers here to get them disabled in mulet.
pref("dom.serviceWorkers.enabled", false);
+pref("dom.push.enabled", false);
// Retain at most 10 processes' layers buffers
pref("layers.compositor-lru-size", 10);
@@ -1081,8 +1081,9 @@ pref("gfx.vsync.refreshdriver", true);
pref("dom.activities.developer_mode_only", "import-app");
// mulet apparently loads firefox.js as well as b2g.js, so we have to explicitly
-// disable serviceworkers here to get them disabled in mulet.
+// disable serviceworkers and push here to get them disabled in mulet.
pref("dom.serviceWorkers.enabled", false);